@@ -9,16 +9,10 @@ import nonebot
 import re
 
 """导入变量"""
-try:
-    # 当 admin_model 为 1 时，调用 API，BOT 不需要为群主。
-    # 当 admin_model 为 2 时，使用 Nonebot 内置函数，BOT 必须为群主。
-    admin_model: int = nonebot.get_driver().config.admin_model
-    skey: str = nonebot.get_driver().config.skey
-    pskey: str = nonebot.get_driver().config.pskey
-except:
-    admin_model: int = 1
-    skey: str = ''
-    pskey: str = ''
+config = nonebot.get_driver().config
+admin_model: int =  getattr(config, "admin_model", 1)
+skey: str =  getattr(config, "skey", "")
+pskey: str =  getattr(config, "pskey", "")
 
 
 """响应部分"""
@@ -45,6 +39,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     # 模式判断
     if admin_model == 1:
         api = f'https://ovooa.com/API/quns/api.php?qq={owner_id}&skey={skey}&pskey={pskey}&group={gid}&uin={qid}&kt=1'
+        print(api)
         msg = await admin_api(api)
         await set_admin.send(f"{msg}", at_sender=True)
     elif admin_model == 2:
@@ -70,7 +65,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     if admin_model == 1:
         api = f'https://ovooa.com/API/quns/api.php?qq={owner_id}&skey={skey}&pskey={pskey}&group={gid}&uin={qid}&kt=2'
         msg = await admin_api(api)
-        await unset_admin.send(f"{msg}")
+        await unset_admin.send(f"{msg}", at_sender=True)
     elif admin_model == 2:
         try:
             await bot.set_group_admin(group_id=gid, user_id=qid, enable=False)
